@@ -29,7 +29,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab import utils  # noqa
 
 __title__ = "python-gitlab"
-__version__ = "2.4.0"
+__version__ = "2.5.0"
 __author__ = "Gauvain Pocentek"
 __email__ = "gauvainpocentek@gmail.com"
 __license__ = "LGPL3"
@@ -45,14 +45,6 @@ REDIRECT_MSG = (
 ALLOWED_KEYSET_ENDPOINTS = ["/projects"]
 
 
-def _sanitize(value):
-    if isinstance(value, dict):
-        return dict((k, _sanitize(v)) for k, v in value.items())
-    if isinstance(value, str):
-        return value.replace("/", "%2F")
-    return value
-
-
 class Gitlab(object):
     """Represents a GitLab server connection.
 
@@ -147,6 +139,7 @@ class Gitlab(object):
         self.pagesdomains = objects.PagesDomainManager(self)
         self.user_activities = objects.UserActivitiesManager(self)
         self.applications = objects.ApplicationManager(self)
+        self.variables = objects.VariableManager(self)
 
     def __enter__(self):
         return self
@@ -322,7 +315,7 @@ class Gitlab(object):
     def _construct_url(self, id_, obj, parameters, action=None):
         if "next_url" in parameters:
             return parameters["next_url"]
-        args = _sanitize(parameters)
+        args = utils.sanitize_parameters(parameters)
 
         url_attr = "_url"
         if action is not None:
